@@ -53,8 +53,6 @@ case "$1" in
             # Debian Jessie / Apache2.4
             [ -d /etc/apache2/conf-available ] || mkdir -p /etc/apache2/conf-available
             ln -sf /etc/benno-web/apache-2.4.conf /etc/apache2/conf-available/benno.conf
-            . /usr/share/apache2/apache2-maintscript-helper
-            apache2_invoke enconf benno
         elif [ ! -f /etc/apache2/conf.d/benno ];then
             mkdir -p /etc/apache2/conf.d
             ln -sf /etc/benno-web/apache-2.2.conf /etc/apache2/conf.d/benno
@@ -127,7 +125,10 @@ case "$1" in
     ;;
 esac
 
+set +e
+[ -x /usr/sbin/a2enconf ] && /usr/sbin/a2enconf benno 2>/dev//null
 [ -x /etc/init.d/apache2 ] && invoke-rc.d apache2 restart
+set -e
 
 
 exit 0
