@@ -384,14 +384,16 @@ class Application extends ApplicationConfig
     function getConfig($parameter,$default='')
     {
         if (isset($this->config[$parameter])) {
-            return  $this->config[$parameter];
-        }
-        else if ($default) {
-            return $default;
+            $parameter = $this->config[$parameter];
         }
         else {
-            return FALSE;
+            $parameter = $default;
         }
+        if (preg_match('/^(true|on|yes)$/i',$parameter)) {
+            $parameter = 1;
+        }
+
+        return $parameter;
     }
 
 
@@ -896,11 +898,8 @@ class Application extends ApplicationConfig
         }
         $this->locale_msg = $locale_msg;
 
-        // date|time format
-        if (preg_match('/^en/',$this->lang)) {
-            $this->date_format = '%m/%d/%Y';
-        }
-        else {
+        $this->date_format = $this->getMsg('DATE_FORMAT');
+        if (!$this->date_format) {
             $this->date_format = '%d.%m.%Y';
         }
         $this->time_format = '%H:%M';
