@@ -42,7 +42,7 @@ $searchstring = $App->getParam('searchmin');
 $queryId = sha1($searchstring);
 $SimpleQuery = new Query($queryId,$archive,$searchstring,$date_from,$date_to);
 $SimpleQuery->setSortOrder($sortOrder);
-$SimpleQuery->setSpam($App->getConfig('SHOW_SPAM'));
+$SimpleQuery->setSpam($App->getConfig('SHOW_SPAM',1));
 $SimpleQuery->type = $App->getSession('searchMaskState');
 
 // reset extended query
